"""Basic Infrastructure API Client."""

from functools import cached_property

from httpx import Client

from .bi_flavor import BiFlavorClient
from .bi_image import BiImageClient
from .bi_resource import BiResourceClient
from .bi_task import BiTaskClient
from .project import ProjectClient


class BiClient:
    """Basic Infrastructure Client."""

    def __init__(self, client: Client, project_id: str) -> None:
        """Create Experiment Client."""
        self._client = client
        self.project_id = project_id
        assert client.base_url is not None, "Expected base_url to be set"

    @cached_property
    def image(self) -> BiImageClient:
        """BI Image Client."""
        return BiImageClient(self._client)

    @cached_property
    def flavor(self) -> BiFlavorClient:
        """BI Flavor Client."""
        return BiFlavorClient(self._client, self.project_id)

    @cached_property
    def task(self) -> BiTaskClient:
        """BI Task Client."""
        return BiTaskClient(self._client)


class BiExperimentClient:
    """Basic Infrastructure Client for a particular experiment."""

    resources: BiResourceClient

    def __init__(self, client: Client, experiment_id: str, project_id: str, project_client: ProjectClient) -> None:
        """Create Basic Infrastructure Client for a particual experiment."""
        self._client = client
        assert client.base_url is not None, "Expected base_url to be set"

        self.experimental_id = experiment_id
        self.project_id = project_id

        self.resources = BiResourceClient(client, experiment_id, project_id, project_client)
